pub struct PrometheusClientLayer { /* private fields */ }Expand description
Add prometheus-client for every operation.
Prometheus Metrics
We provide several metrics, please see the documentation of observe module.
For a more detailed explanation of these metrics and how they are used, please refer to the Prometheus documentation.
Examples
let mut registry = prometheus_client::registry::Registry::default();
let op = Operator::new(services::Memory::default())?
.layer(PrometheusClientLayer::builder().register(&mut registry))
.finish();
// Write data into object test.
op.write("test", "Hello, World!").await?;
// Read data from the object.
let bs = op.read("test").await?;
info!("content: {}", String::from_utf8_lossy(&bs.to_bytes()));
// Get object metadata.
let meta = op.stat("test").await?;
info!("meta: {:?}", meta);
// Export prometheus metrics.
let mut buf = String::new();
prometheus_client::encoding::text::encode(&mut buf, ®istry).unwrap();
println!("## Prometheus Metrics");
println!("{}", buf);Implementations
Sourceimpl PrometheusClientLayer
impl PrometheusClientLayer
Sourcepub fn builder() -> PrometheusClientLayerBuilder
pub fn builder() -> PrometheusClientLayerBuilder
Create a PrometheusClientLayerBuilder to set the configuration of metrics.