PrometheusClientLayerBuilder

Struct PrometheusClientLayerBuilder 

pub struct PrometheusClientLayerBuilder { /* private fields */ }
PrometheusClientLayerBuilder is a config builder to build a PrometheusClientLayer.

Implementations

Source

impl PrometheusClientLayerBuilder

pub fn bytes_buckets(self, buckets: Vec<f64>) -> Self

Set buckets for bytes related histogram like operation_bytes.

pub fn bytes_rate_buckets(self, buckets: Vec<f64>) -> Self

Set buckets for bytes rate related histogram like operation_bytes_rate.

pub fn entries_buckets(self, buckets: Vec<f64>) -> Self

Set buckets for entries related histogram like operation_entries.

pub fn entries_rate_buckets(self, buckets: Vec<f64>) -> Self

Set buckets for entries rate related histogram like operation_entries_rate.

pub fn duration_seconds_buckets(self, buckets: Vec<f64>) -> Self

Set buckets for duration seconds related histogram like operation_duration_seconds.

pub fn ttfb_buckets(self, buckets: Vec<f64>) -> Self

Set buckets for ttfb related histogram like operation_ttfb_seconds.

pub fn disable_label_root(self, disable: bool) -> Self

The ‘root’ label might have risks of being high cardinality, users can choose to disable it when they found it’s not useful for their metrics.

pub fn register(self, registry: &mut Registry) -> PrometheusClientLayer

Register the metrics into the registry and return a PrometheusClientLayer.

Example
// Pick a builder and configure it.
let builder = services::Memory::default();
let mut registry = prometheus_client::registry::Registry::default();

let _ = Operator::new(builder)?
    .layer(PrometheusClientLayer::builder().register(&mut registry))
    .finish();